Defines criteria for ending the optimization search
stopping_criteria(
df,
round,
stop,
min_improvement,
stop_rounds = 3,
reset_stop_rounds = TRUE,
stop_metric = "auc"
)a matrix of F-Measures for different thresholds or the highest F-Measure value
data.frame. includes the metrics of ensemblem model performance
integer. the current round of optimization
integer. current round of stopping penalty
numeric. specifies the minimum improvement in model evaluation metric to qualify further optimization search.
integer. number of stoping rounds, in case the model stops improving
logical. if TRUE, everytime the model improves the stopping rounds penalty is resets to 0.
character. model stopping metric. the default is "auc",
but "aucpr" and "mcc" are also available.
E. F. Haghish